@@ -1,15 +1,20 @@
 import asyncio
-import aiohttp
+import logging
 import time
-from .const import Region
 from functools import wraps
 from urllib.parse import quote as _uriquote
 
+import aiohttp
+
+from sc2api.const import Region
+from sc2api.error import Sc2ApiAuthenticationError
+
+logger = logging.getLogger(__name__)
+
 
 class RateLimiter():
     """Limits to {limit} number of connections and {rate} requests/second"""
-
-    def __init__(self, rate, limit):
+    def __init__(self, rate: float, limit: float) -> None:
         self.sem = asyncio.Semaphore(limit)
         self.rate = rate
 
@@ -20,15 +25,15 @@ class RateLimiter():
                 start = time.monotonic()
                 result = await fn(*args, **kwargs)
                 diff = time.monotonic() - start
-                sleep_for = max(0, 1/self.rate-diff)
+                sleep_for = max(0, 1 / self.rate - diff)
                 await asyncio.sleep(sleep_for)
                 return result
+
         return decorated
 
 
 class Sc2Api:
-
-    def __init__(self, client_id, client_secret):
+    def __init__(self, client_id: str, client_secret: str) -> None:
         self.client_id = client_id
         self.client_secret = client_secret
         self._rh = RequestHandler(self.client_id, self.client_secret)
@@ -54,15 +59,21 @@ class DataApi:
         self._rh = request_handler
 
     async def league(self, region, season_id, queue_id, team_type, league_id):
-        route = Route('GET', "/data/sc2/league/{season_id}/{queue_id}/{team_type}/{league_id}",
-                      base=f"https://{region.name}.api.blizzard.com",
-                      season_id=season_id, queue_id=queue_id, team_type=team_type, league_id=league_id)
+        route = Route(
+            'GET',
+            "/data/sc2/league/{season_id}/{queue_id}/{team_type}/{league_id}",
+            base=f"https://{region.name}.api.blizzard.com",
+            season_id=season_id,
+            queue_id=queue_id,
+            team_type=team_type,
+            league_id=league_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
     async def ladder(self, region, ladder_id):
-        route = Route(
-            'GET', "/data/sc2/ladder/{ladder_id}",
-            base=f"https://{region.name}.api.blizzard.com", ladder_id=ladder_id)
+        route = Route('GET',
+                      "/data/sc2/ladder/{ladder_id}",
+                      base=f"https://{region.name}.api.blizzard.com",
+                      ladder_id=ladder_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
 
@@ -71,34 +82,45 @@ class ProfileApi:
         self._rh = request_handler
 
     async def static(self, region_id):
-        route = Route(
-            'GET', "/sc2/static/profile/{region_id}", region_id=region_id)
+        route = Route('GET',
+                      "/sc2/static/profile/{region_id}",
+                      region_id=region_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
     async def metadata(self, region_id, realm_id, profile_id):
         route = Route(
-            'GET', "/sc2/metadata/profile/{region_id}/{realm_id}/{profile_id}",
-            region_id=region_id, realm_id=realm_id, profile_id=profile_id)
+            'GET',
+            "/sc2/metadata/profile/{region_id}/{realm_id}/{profile_id}",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
     async def profile(self, region_id, realm_id, profile_id):
-        route = Route(
-            'GET', "/sc2/profile/{region_id}/{realm_id}/{profile_id}",
-            region_id=region_id, realm_id=realm_id, profile_id=profile_id)
-        return await self._rh.request(route, params={'locale': 'en_US'})
-
-    async def ladder_summary(self, region_id, realm_id, profile_id):
         route = Route('GET',
-                      "/sc2/profile/{region_id}/{realm_id}/{profile_id}/ladder/summary",
-                      region_id=region_id, realm_id=realm_id,
+                      "/sc2/profile/{region_id}/{realm_id}/{profile_id}",
+                      region_id=region_id,
+                      realm_id=realm_id,
                       profile_id=profile_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
+    async def ladder_summary(self, region_id, realm_id, profile_id):
+        route = Route(
+            'GET',
+            "/sc2/profile/{region_id}/{realm_id}/{profile_id}/ladder/summary",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id)
+        return await self._rh.request(route, params={'locale': 'en_US'})
+
     async def ladder(self, region_id, realm_id, profile_id, ladder_id):
-        route = Route('GET',
-                      "/sc2/profile/{region_id}/{realm_id}/{profile_id}/ladder/{ladder_id}",
-                      region_id=region_id, realm_id=realm_id,
-                      profile_id=profile_id, ladder_id=ladder_id)
+        route = Route(
+            'GET',
+            "/sc2/profile/{region_id}/{realm_id}/{profile_id}/ladder/{ladder_id}",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id,
+            ladder_id=ladder_id)
         return await self._rh.request(route, params={'locale': 'en_US'})
 
 
@@ -107,12 +129,14 @@ class LadderApi:
         self._rh = request_handler
 
     async def grand_master(self, region_id):
-        route = Route('GET', "/sc2/ladder/grandmaster/{region_id}",
+        route = Route('GET',
+                      "/sc2/ladder/grandmaster/{region_id}",
                       region_id=region_id)
         return await self._rh.request(route)
 
     async def season(self, region_id):
-        route = Route('GET', "/sc2/ladder/season/{region_id}",
+        route = Route('GET',
+                      "/sc2/ladder/season/{region_id}",
                       region_id=region_id)
         return await self._rh.request(route)
 
@@ -122,8 +146,7 @@ class AccountApi:
         self._rh = request_handler
 
     async def player(self, account_id):
-        route = Route('GET', "/sc2/player/:accountId",
-                      account_id=account_id)
+        route = Route('GET', "/sc2/player/:accountId", account_id=account_id)
         return await self._rh.request(route)
 
 
@@ -132,30 +155,37 @@ class LegacyApi:
         self._rh = request_handler
 
     async def profile(self, region_id, realm_id, profile_id):
-        route = Route('GET',
-                      "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}",
-                      region_id=region_id, realm_id=realm_id,
-                      profile_id=profile_id)
+        route = Route(
+            'GET',
+            "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id)
         return await self._rh.request(route)
 
     async def ladders(self, region_id, realm_id, profile_id):
-        route = Route('GET',
-                      "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}/ladders",
-                      region_id=region_id, realm_id=realm_id,
-                      profile_id=profile_id)
+        route = Route(
+            'GET',
+            "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}/ladders",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id)
         return await self._rh.request(route)
 
     async def match_history(self, region_id, realm_id, profile_id):
-        route = Route('GET',
-                      "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}/matches",
-                      region_id=region_id, realm_id=realm_id,
-                      profile_id=profile_id)
+        route = Route(
+            'GET',
+            "/sc2/legacy/profile/{region_id}/{realm_id}/{profile_id}/matches",
+            region_id=region_id,
+            realm_id=realm_id,
+            profile_id=profile_id)
         return await self._rh.request(route)
 
     async def ladder(self, region_id, ladder_id):
         route = Route('GET',
                       "/sc2/legacy/ladder/{region_id}/{ladder_id}",
-                      region_id=region_id, ladder_id=ladder_id)
+                      region_id=region_id,
+                      ladder_id=ladder_id)
         return await self._rh.request(route)
 
     async def achievements(self, region_id):
@@ -172,8 +202,7 @@ class LegacyApi:
 
 
 class RequestHandler:
-
-    def __init__(self, client_id, client_secret):
+    def __init__(self, client_id: str, client_secret: str) -> None:
         self.client_id = client_id
         self.client_secret = client_secret
 
@@ -191,22 +220,27 @@ class RequestHandler:
 
         async with self._session.get(url, auth=auth, params=params) as resp:
             data = await resp.json()
-
-        self.token = data['access_token']
-        self.token_expires_at = time.time() + data['expires_in']*0.95
+        try:
+            self.token = data['access_token']
+        except KeyError:
+            logger.debug("Wrong credentials provided")
+            raise Sc2ApiAuthenticationError("Wrong credentials provided")
+        self.token_expires_at = time.time() + data['expires_in'] * 0.95
 
     async def close(self):
         if self._session:
             await self._session.close()
 
-    @ RateLimiter(100, 100)
+    @RateLimiter(100, 100)
     async def request(self, route, **kwargs):
         if self.token_expires_at < time.time():
             await self.update_token()
         method = route.method
         url = route.url
-        kwargs['params'] = {'access_token': self.token,
-                            **kwargs.get('params', {})}
+        kwargs['params'] = {
+            'access_token': self.token,
+            **kwargs.get('params', {})
+        }
         async with self._session.request(method, url, **kwargs) as r:
             try:
                 data = await r.json()
@@ -225,7 +259,9 @@ class Route:
         url = self.base + self.path
         if params:
             self.url = url.format(
-                **{k: _uriquote(v) if isinstance(v, str) else v
-                   for k, v in params.items()})
+                **{
+                    k: _uriquote(v) if isinstance(v, str) else v
+                    for k, v in params.items()
+                })
         else:
             self.url = url
